curve25519

package
v0.0.0-...-5c775dd Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 24, 2024 License: MIT, BSD-3-Clause Imports: 1 Imported by: 0

Documentation

Overview

Package curve25519 provides an implementation of the X25519 function, which performs scalar multiplication on the elliptic curve known as Curve25519. See RFC 7748.

Starting in Go 1.20, this package is a wrapper for the X25519 implementation in the crypto/ecdh package.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ScalarBaseMult

func ScalarBaseMult(dst, scalar []byte) error

ScalarBaseMult sets dst to the product scalar * base where base is the standard generator.

It is recommended to use the X25519 function with Basepoint instead, as copying into fixed size arrays can lead to unexpected bugs.

Types

This section is empty.

Directories

Path Synopsis
internal
field
Package field implements fast arithmetic modulo 2^255-19.
Package field implements fast arithmetic modulo 2^255-19.

Jump to