Documentation
¶
Overview ¶
Package curve25519 provides an implementation of the X25519 function, which performs scalar multiplication on the elliptic curve known as Curve25519. See RFC 7748.
Starting in Go 1.20, this package is a wrapper for the X25519 implementation in the crypto/ecdh package.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ScalarBaseMult ¶
ScalarBaseMult sets dst to the product scalar * base where base is the standard generator.
It is recommended to use the X25519 function with Basepoint instead, as copying into fixed size arrays can lead to unexpected bugs.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.